@@ -15,6 +15,7 @@
 #include <ktexteditor/configpage.h>
 
 class KateFileTreePlugin;
+class QComboBox;
 
 class KateFileTreeConfigPage : public KTextEditor::ConfigPage
 {
@@ -44,8 +45,10 @@ private:
     class QGroupBox *gbEnableShading;
     class KColorButton *kcbViewShade, *kcbEditShade;
     class QLabel *lEditShade, *lViewShade, *lSort, *lMode;
-    class KComboBox *cmbSort, *cmbMode;
+    QComboBox *cmbSort, *cmbMode;
     class QCheckBox *cbShowFullPath;
+    class QCheckBox *cbShowToolbar;
+    class QCheckBox *cbShowClose;
     KateFileTreePlugin *m_plug;
 
     bool m_changed = false;
