@@ -255,6 +255,7 @@ struct LSPCompletionItem {
     LSPMarkupContent documentation;
     QString sortText;
     QString insertText;
+    QList<LSPTextEdit> additionalTextEdits;
     // Intentionally disabled because doesn't work well
     // with KTE. See: https://invent.kde.org/utilities/kate/-/merge_requests/438
     //     LSPTextEdit textEdit;
@@ -376,9 +377,15 @@ struct LSPCommand {
     QJsonArray arguments;
 };
 
+struct LSPTextDocumentEdit {
+    LSPVersionedTextDocumentIdentifier textDocument;
+    QList<LSPTextEdit> edits;
+};
+
 struct LSPWorkspaceEdit {
     // supported part for now
     QHash<QUrl, QList<LSPTextEdit>> changes;
+    QList<LSPTextDocumentEdit> documentChanges;
 };
 
 struct LSPCodeAction {
